﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Infragistics.Olap;
using Infragistics.Olap.Data;

namespace PivotGridCustomDataSelector
{
    using Infragistics.Olap.Data.Base;
    using Infragistics.Olap.FlatData;

    public partial class MainPage : UserControl
    {
        private FlatDataSource _flatDataSource;

        public MainPage()
        {
            InitializeComponent();

            // create the connection settings
            FlatDataConnectionSettings connectionSettings =
                new FlatDataConnectionSettings { ItemsSource = ProductData.GenerateData() };

            // create the provider in order to be able to change the aggregation context
            FlatDataModelProvider flatDataModelProvider =
                new FlatDataModelProvider(connectionSettings);

            // set your own aggregator
            flatDataModelProvider.AggregationContext = new CustomAggregator();

            // create the flat data source
            this._flatDataSource = new FlatDataSource(flatDataModelProvider);
            this._flatDataSource.Cube = DataSourceBase.GenerateInitialCube(typeof(ProductData).Name);

            this.pivotGrid.DataSource = this._flatDataSource;

            // initialize the collections of your data selector
            this._flatDataSource.LoadDimensionsCompleted += (sender, args) =>
                {
                    this.dimensionsListBox.ItemsSource = this._flatDataSource.Cube.Dimensions;
                };

            this._flatDataSource.LoadMeasuresCompleted += (sender, args) =>
                {
                    this.measuresListBox.ItemsSource = this._flatDataSource.Cube.Measures;
                };
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            IOlapViewModel olapViewModel = this._flatDataSource;

            // stop refresh of the pivot grid
            olapViewModel.DeferredLayoutUpdate = true;
            
            // clear the ola data
            olapViewModel.Columns.Clear();
            olapViewModel.Rows.Clear();
            olapViewModel.Filters.Clear();
            olapViewModel.Measures.Clear();

            // fill the columns (rows, filters)
            foreach (var selectedItem in this.dimensionsListBox.SelectedItems)
            {
                IDimension dimension = (IDimension)selectedItem;
                IFilterViewModel filterViewModel =
                    olapViewModel.CreateFilterViewModel(dimension.Hierarchies[0]);

                olapViewModel.Columns.Add(filterViewModel);
            }

            // fill the measures
            foreach (var selectedItem in this.measuresListBox.SelectedItems)
            {
                IMeasureViewModel measureViewModel =
                    olapViewModel.CreateMeasureViewModel((Measure)selectedItem);

                olapViewModel.Measures.Add(measureViewModel);

                if (olapViewModel.SupportsAggregations)
                {
                    
                }
            }

            // refresh the grid with new data
            this.pivotGrid.DataSource.DeferredLayoutUpdate = false;
        }        
    }
}
